import numpy as np

from matplotlib import pyplot as plt
from scipy import optimize as opt

def ringdown(tt, A, tau):
    return A*np.exp(-tt/tau)

tt, amp = np.loadtxt('butterfly.txt', unpack=1)[:,6400:]
start = '2015-07-20 11:08:47 Z'
f0 = 6053.805
tt -= tt[0]
q = opt.curve_fit(ringdown, tt, amp, p0=(500, 1200))
plt.clf()
plt.semilogy(tt, amp, alpha=0.6, label='Data')
plt.semilogy(tt, ringdown(tt, *q[0]), label=r'Fit to $A \mathrm{e}^{-t/\tau}$', c='r')
plt.xlabel('Time [s]')
plt.ylabel('rms mode amplitude [arb.]')
plt.text(2400, 600, 'Start time: {}'.format(start))
plt.text(2400, 400, r'Channel: H1:SUS-ETMY_L2_DAMP_MODE9_BLRMS')
plt.text(2400, 300, r'$A = {:.0f}$'.format(q[0][0]))
plt.text(2400, 220, r'$\tau = {:.0f}$ s'.format(q[0][1]))
plt.text(2400, 150, r'Frequency: {} Hz'.format(f0))
plt.legend(loc=3)
plt.title('EY butterfly mode ringdown')
plt.tight_layout()
plt.savefig('ey_butterfly.pdf')

